traitlets: A configuration system for Python applications
=========================================================

Description
-----------

Traitlets Python config system

A configuration system for Python applications.
